subsetByRegion: Subset a TopDomData Object by Region

View source: R/subsetByRegion.R

subsetByRegionR Documentation

Subset a TopDomData Object by Region

Description

Subset a TopDomData Object by Region

Usage

subsetByRegion(data, region, margin = 1/2)

Arguments

data

A TopDomData object.

region

A TopDom domain (a data.frame).

margin

An non-negative numeric specifying the additional margin extracted around the domain. If margin < 1, then the size of the margin is relative to the size of the domain.

Value

A TopDomData object.

Author(s)

Henrik Bengtsson.


TopDom documentation built on Aug. 31, 2026, 5:06 p.m.